@@ -19,10 +19,10 @@ from tgtk.core.user_settings import handle_user_settings, handle_user_setting_ca
 from functools import partial
 from tgtk.functions.rclone_upload import get_config, rclone_driver
 from tgtk.functions.admin_check import is_admin
-from tk import upload_db,var_db,tor_db,user_db, uptime
+from tgtk import upload_db,var_db,tor_db,user_db, uptime
 import asyncio as aio
 import re,logging,time,os,psutil,shutil
-from tk import __version__
+from tgtk import __version__
 from tgtk.core.ttk_ytdl import handle_ytdl_command,handle_ytdl_callbacks,handle_ytdl_file_download,handle_ytdl_playlist,handle_ytdl_playlist_down
 from tgtk.functions.instadl import _insta_post_downloader
 torlog = logging.getLogger(__name__)
