@@ -3,7 +3,7 @@
 
 from ..consts.ExecVarsSample import ExecVars
 from ..core.database_handle import tkdb
-from tk import SessionVars
+from tgtk import SessionVars
 import os
 
 def get_val(variable):
