@@ -3,7 +3,7 @@
 
 from telethon.tl.types import KeyboardButtonCallback,KeyboardButton
 from telethon import events
-from tk import SessionVars
+from tgtk import SessionVars
 import asyncio as aio
 from .getVars import get_val
 from .database_handle import tkdb
